Package: benchr
Title: High Precise Measurement of R Expressions Execution Time
Version: 0.2.5
Description: Provides infrastructure to accurately measure and compare
    the execution time of R expressions.
Authors@R: c(
    person("Artem", "Klevtsov", role = c("aut", "cre"),
           email = "a.a.klevtsov@gmail.com",
           comment = c(ORCID = "0000-0003-0492-6647")),
    person("Anton", "Antonov", role = "ctb",
           email = "tonytonov@gmail.com"),
    person("Philipp", "Upravitelev", role = "ctb",
           email = "upravitelev@gmail.com"))
URL: https://gitlab.com/artemklevtsov/benchr
BugReports: https://gitlab.com/artemklevtsov/benchr/issues
License: GPL (>= 2)
Encoding: UTF-8
ByteCompile: yes
LazyData: yes
Imports: Rcpp (>= 0.12.11), RcppProgress, stats, graphics
Suggests: tinytest, ggplot2 (>= 3.3.0)
LinkingTo: Rcpp, RcppProgress
SystemRequirements: C++11
RoxygenNote: 7.0.2
Collate: 'RcppExports.R' 'order.R' 'utils.R' 'benchmark.R'
        'benchr-package.R' 'boxplot.R' 'mean.R' 'plot.R' 'units.R'
        'summary.R' 'print.R' 'zzz.R'
NeedsCompilation: yes
Packaged: 2020-03-07 06:11:26 UTC; unikum
Author: Artem Klevtsov [aut, cre] (<https://orcid.org/0000-0003-0492-6647>),
  Anton Antonov [ctb],
  Philipp Upravitelev [ctb]
Maintainer: Artem Klevtsov <a.a.klevtsov@gmail.com>
Repository: CRAN
Date/Publication: 2020-03-07 06:30:03 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-24 04:35:44 UTC; unix
Archs: benchr.so.dSYM
