# Generated by roxygen2: do not edit by hand

S3method(boxplot,benchmark)
S3method(mean,benchmark)
S3method(plot,benchmark)
S3method(print,benchmark)
S3method(print,summaryBenchmark)
S3method(summary,benchmark)
export(benchmark)
export(timer_precision)
import(RcppProgress)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,boxplot)
importFrom(graphics,boxplot.default)
importFrom(graphics,legend)
importFrom(graphics,plot)
importFrom(graphics,plot.default)
importFrom(stats,quantile)
importFrom(stats,wilcox.test)
useDynLib(benchr, .registration=TRUE)
